@@ -61,10 +61,14 @@ class CryptoFieldsConfig(BaseModel):
     # === Django Revision Settings (for django-audit-fields dependency) ===
     ignore_git_dir: bool = Field(
         default=True,
-        description="Ignore git directory for django-revision (set DJANGO_REVISION_IGNORE_WORKING_DIR=True)"
+        description=(
+            "Ignore git directory for django-revision. "
+            "When True, version is discovered from: package metadata → pyproject.toml → VERSION file. "
+            "Prevents 'not recommended' warning from settings.REVISION fallback."
+        )
     )
 
-    def to_django_settings(self, base_dir: Path, is_production: bool, debug: bool) -> dict:
+    def to_django_settings(self, base_dir: Path, is_production: bool, debug: bool, project_version: str = "1.0.0") -> dict:
         """
         Convert to Django settings dictionary with environment-aware defaults.
 
@@ -72,6 +76,7 @@ class CryptoFieldsConfig(BaseModel):
             base_dir: Django project BASE_DIR
             is_production: Whether running in production mode
             debug: Whether debug mode is enabled
+            project_version: Project version to use for REVISION (default: "1.0.0")
 
         Returns:
             Dictionary of django-crypto-fields settings
@@ -107,14 +112,17 @@ class CryptoFieldsConfig(BaseModel):
             "AUTO_CREATE_KEYS": auto_create_keys,
         }
 
-        # Disable django-revision git integration (required by django-audit-fields)
-        # RevisionField will use package metadata or pyproject.toml instead
-        if self.ignore_git_dir:
-            settings["DJANGO_REVISION_IGNORE_WORKING_DIR"] = True
-            # Completely disable django-revision metadata checks to avoid errors
-            settings["DJANGO_REVISION_IGNORE_METADATA"] = True
-            # Set static revision to satisfy django-revision requirements
-            settings["REVISION"] = "1.0.0"
+        # Fix django-revision (required by django-audit-fields dependency)
+        # Disable all automatic version detection and use project version directly
+        # This prevents "A distribution name is required" error when package metadata is not available
+        settings.update({
+            "REVISION": project_version,
+            "APP_NAME": "",  # Empty to prevent package metadata lookup
+            "DJANGO_REVISION_IGNORE_METADATA": True,  # Don't use importlib.metadata.version()
+            "DJANGO_REVISION_IGNORE_TOML_FILE": True,  # Don't read pyproject.toml
+            "DJANGO_REVISION_IGNORE_VERSION_FILE": True,  # Don't read VERSION file
+            "DJANGO_REVISION_IGNORE_WORKING_DIR": True,  # Don't use git
+        })
 
         return settings
 
