@@ -4,8 +4,8 @@ Translation modules.
 Text and JSON translation with caching and batch processing.
 """
 
-from .text_translator import TextTranslator, TranslationError, LanguageDetectionError
 from .json_translator import JsonTranslator
+from .text_translator import LanguageDetectionError, TextTranslator, TranslationError
 
 __all__ = [
     'TextTranslator',
